/*
 * List objects in a filesystem.
 *
 * Copyright (C) 2019, 2022 Paul Boddie <paul@boddie.org.uk>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA  02110-1301, USA
 */

#include <stdio.h>

#include <ext2fs/ext2fs.h>

#include "format.h"
#include "image.h"
#include "session.h"
#include "utils.h"



/* List objects in the filesystem image. */

int list(ext2_filsys fs, int argc, char *argv[])
{
    int i;
    char *path;

    for (i = 0; i < argc; i++)
    {
        path = argv[i];

        /* Emit each object. */

        puts(path);

        /* List individual files or directories. */

        if (utils_list_dir(fs, path))
        {
            fprintf(stderr, "Failed to list object: %s\n", path);
            return 1;
        }
    }

    return 0;
}

/* vim: tabstop=4 expandtab shiftwidth=4
*/
