/*
 * Support for executing code in new tasks and threads.
 *
 * Copyright (C) 2022, 2023 Paul Boddie <paul@boddie.org.uk>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA  02110-1301, USA
 */

#include <l4/re/env.h>
#include <l4/sys/err.h>
#include <l4/util/util.h>

#include <exec/process_creator.h>
#include <systypes/fcntl.h>

#include <stdio.h>



int main(int argc, char *argv[])
{
  long err;

  if (argc < 3)
  {
    printf("Need a region mapper and the actual program to run.\n");
    return 1;
  }

  char *rm_filename = argv[1];
  char *program_filename = argv[2];

  ProcessCreator creator(rm_filename);
  file_t *program_file = client_open(program_filename, O_RDONLY);

  if (!client_opened(program_file))
  {
    printf("Could not open program file.\n");
    return 1;
  }

  err = creator.start(program_file, argc - 2, (const char **) argv + 2);

  if (err)
  {
    printf("Could not start process: %s\n", l4sys_errtostr(err));
    return 1;
  }

  printf("Finished program initiation.\n");
  printf("End of test.\n");

  /* NOTE: Should be able to obtain a notification for when the program
           finishes, which might be done using a capability deletion IRQ.
           Eventually, this program will operate as a server, invoking new
           programs and handling termination. This test would then merely
           involve the invocation of a utility function. */

  while (1)
    l4_sleep_forever();

  return 0;
}

/* vim: tabstop=2 expandtab shiftwidth=2
*/
